@@ -9,12 +9,12 @@ def get_data(path):
     return os.path.join(_ROOT, 'data', path)
 
 def load_meat():
-    import pandas as pd
     filename = get_data("meat.csv")
-    return pd.read_csv(filename, parse_dates=[0])
+    df = pd.read_csv(filename, parse_dates=[0])
+    return df
 
 def load_births():
-    import pandas as pd
     filename = get_data("births_by_month.csv")
-    return pd.read_csv(filename, parse_dates=[0])
+    df =  pd.read_csv(filename, parse_dates=[0])
+    return df
 
